==> smuxi_0.8.orig.tar.gz: smuxi-0.8/src/Common/Defines.cs <==
/*
 * $Id: Page.cs 111 2006-02-20 23:10:45Z meebey $
 * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GtkGnome/Page.cs $
 * $Rev: 111 $
 * $Author: meebey $
 * $Date: 2006-02-21 00:10:45 +0100 (Tue, 21 Feb 2006) $
 *
 * Smuxi - Smart MUltipleXed Irc
 *
 * Copyright (c) 2008 Mirco Bauer <meebey@meebey.net>
 *
 * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

using System;

namespace Smuxi.Common
{
    public static class Defines
    {
        private static readonly string f_InstallPrefix = "/usr/local";
        private static readonly string f_TwitterApiKey = "G0fxRfJqvcMPAuNat15YQ|j77MQDIuZJFa0CXehYzGPBZidF8DT3OXAi6sb5ucE";

        public static string InstallPrefix {
            get {
                return f_InstallPrefix;
            }
        }

        public static string TwitterApiKey {
            get {
                return f_TwitterApiKey;
            }
        }
    }
}

==> smuxi_0.8.9.1.orig.tar.gz: smuxi-0.8.9.1/src/Common/Defines.cs <==
/*
 * Smuxi - Smart MUltipleXed Irc
 *
 * Copyright (c) 2008 Mirco Bauer <meebey@meebey.net>
 *
 * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

using System;

namespace Smuxi.Common
{
    public static class Defines
    {
        public const string GitBranch   = "master";
        public const string GitCommitHash = "8312f5b";

        private static readonly string f_InstallPrefix = "/usr/local";
        private static readonly string f_DistVersion = "master/8312f5b";
        private static readonly string f_TwitterApiKey = "60QV2qQx9cS7y1BJDbgAA|2VgD6qQKddsF5HYQ0TrRgs3tFTnCwDONBmRlTmG658";

        public static string InstallPrefix {
            get {
                return f_InstallPrefix;
            }
        }

        public static string TwitterApiKey {
            get {
                return f_TwitterApiKey;
            }
        }

        public static string GitVersion {
            get {
                if (String.IsNullOrEmpty(GitBranch) ||
                    String.IsNullOrEmpty(GitCommitHash)) {
                    return String.Empty;
                }

                return String.Format("{0}/{1}", GitBranch, GitCommitHash);
            }
        }

        public static string DistVersion {
            get {
                return f_DistVersion;
            }
        }
    }
}
